# isitfit

[![PyPI version](https://badge.fury.io/py/isitfit.svg)](https://badge.fury.io/py/isitfit)

A simple command-line tool to check if an AWS EC2/Redshift account is fit or underused.


## Documentation

Check https://isitfit.autofitcloud.com


## Changelog

Check [CHANGELOG.md](CHANGELOG.md)


## License

Apache License 2.0. Check file [LICENSE](LICENSE)


## Developer notes

Check [DEVELOPER.md](DEVELOPER.md)

